migrations Package
==================

:mod:`0001_initial` Module
--------------------------

.. automodule:: yawf.revision.migrations.0001_initial
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`0002_add_is_created_field` Module
---------------------------------------

.. automodule:: yawf.revision.migrations.0002_add_is_created_field
    :members:
    :undoc-members:
    :show-inheritance:

